==> uo_vra_netdot_client-0.3.tar.gz: uo_vra_netdot_client-0.3/setup.py <==
from distutils.core import setup
setup(
    name = 'uo_vra_netdot_client',         # How you named your package folder (MyLib)
    packages = [''],   # Chose the same as "name"
    version = '0.3',      # Start with a small number and increase it with every change you make
    license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
    description = 'Package for connecting VRealize Automation to Netdot for IPAM',   # Give a short description about your library
    author = 'University of Oregon',                   # Type in your name
    author_email = 'systems@uoregon.edu',      # Type in your E-Mail
    url = 'https://git.uoregon.edu/projects/ISV/repos/uo_vra_netdot_client/browse',   # Provide either the link to your github or to your website
    # download_url = 'NOT SURE YET',    # I explain this later on
    keywords = ['IPAM', 'VRA', 'NETDOT'],   # Keywords that define your package best
    install_requires=[            # I get to this in a second
            'beautifulsoup4',
        ],
    classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
    ],
)

==> uo_vra_netdot_client-0.4.tar.gz: uo_vra_netdot_client-0.4/setup.py <==
from distutils.core import setup
setup(
    name = 'uo_vra_netdot_client',         # How you named your package folder (MyLib)
    packages = ['uo_vra_netdot_client'],   # Chose the same as "name"
    version = '0.4',      # Start with a small number and increase it with every change you make
    license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
    description = 'Package for connecting VRealize Automation to Netdot for IPAM',   # Give a short description about your library
    author = 'University of Oregon',                   # Type in your name
    author_email = 'systems@uoregon.edu',      # Type in your E-Mail
    url = 'https://git.uoregon.edu/projects/ISV/repos/uo_vra_netdot_client/browse',   # Provide either the link to your github or to your website
    # download_url = 'NOT SURE YET',    # I explain this later on
    keywords = ['IPAM', 'VRA', 'NETDOT'],   # Keywords that define your package best
    install_requires=[            # I get to this in a second
            'beautifulsoup4',
        ],
    classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
    ],
)
